/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __WINDOWS_H__
#define __WINDOWS_H__


#include "advapi32.h"
#include "commdlg.h"
#include "gdi32.h"
#include "kernel32.h"
#include "msvcrt.h"
#include "ole32.h"
#include "oleaut32.h"
#include "shell32.h"
#include "tchar.h"
#include "user32.h"
#include "version.h"
#include "winmm.h"
#include "winsock.h"


#endif /* __WINDOWS_H__ */
